==> cejs-4.5.1.tgz: package/application/locale/resources/ko-KR.js <==
/*	Localized messages of CeL.
	This file is auto created by auto-generate tool: build.nodejs(.js) @ 2022.
*/'use strict';typeof CeL==='function'&&CeL.application.locale.gettext.set_text({
	"Loading...": "\ubd88\ub7ec\uc624\ub294 \uc911...",
	"\u2191Back to TOC": "\u2191\ubaa9\ucc28\ub85c \ub3cc\uc544\uac00\uae30",
	"Language": "\uc5b8\uc5b4",
	"Abandon change": "\ubcc0\uacbd\uc0ac\ud56d \ubc84\ub9ac\uae30",
	"soon": "\uace7",
	"%1 hours ago": "%1\uc2dc\uac04 \uc804",
	"%1 days ago": "%1\uc77c \uc804",
	"%1 days later": "%1\uc77c \ud6c4",
	"\u4e2d\u570b": "\uc911\uad6d",
	"\u8f38\u51fa\u683c\u5f0f": "\ucd9c\ub825 \ud615\uc2dd",
	"\u554f\u984c\u56de\u5831": "\ud53c\ub4dc\ubc31",
	"\u5206\u985e": "\uadf8\ub8f9",
	"Julian calendar": "\uc728\ub9ac\uc6b0\uc2a4\ub825",
	"Unix time": "\uc720\ub2c9\uc2a4 \uc2dc\uac04",
	"\u4e0a\u5f26": "1\ubd84\uae30",
	"Italy": "\uc774\ud0c8\ub9ac\uc544",
	"France": "\ud504\ub791\uc2a4",
	"Norway": "\ub178\ub974\uc6e8\uc774",
	"\u6240\u6709\u570b\u5bb6": "\ubaa8\ub4e0 \uad6d\uac00",
	"\u7d00\u5e74\u7dda\u5716\u9078\u9805\uff1a": "\ud0c0\uc784\ub77c\uc778 \uc635\uc158:",
	"\u6642\u5340\uff1a": "\uc2dc\uac04\ub300:",
	"Usage:": "\uc0ac\uc6a9\ubc95:",
	"option=value": "\uc635\uc158=\uac12",
	"Options:": "\uc635\uc158:",
	"file": "\ud30c\uc77c",
	"files": "\ud30c\uc77c",
	"directory": "\ub514\ub809\ud130\ub9ac",
	"directories": "\ub514\ub809\ud130\ub9ac",
	"fso_file": "\ud30c\uc77c \uacbd\ub85c",
	"fso_files": "\ud30c\uc77c \uacbd\ub85c",
	"fso_directory": "\ub514\ub809\ud130\ub9ac \uacbd\ub85c",
	"fso_directories": "\ub514\ub809\ud130\ub9ac \uacbd\ub85c",
	"Using proxy server: %1": "\ud504\ub85d\uc2dc \uc11c\ubc84 \uc0ac\uc6a9: %1",
	"\u672a\u8a2d\u5b9a User-Agent\u3002": "User-Agent\uac00 \uc124\uc815\ub418\uc5b4 \uc788\uc9c0 \uc54a\uc2b5\ub2c8\ub2e4.",
	"\u7531\u547d\u4ee4\u5217": "\uba85\ub839 \uc904\uc5d0\uc11c",
	"work_data.title": "\uc791\ud488 \uc81c\ubaa9",
	"work_data.id": "\uc791\ud488 ID",
	"work_data.url": "URL",
	"work_data.directory": "\uc2a4\ud1a0\ub9ac\uc9c0 \ub514\ub809\ud130\ub9ac",
	"\u7db2\u5740\u7121\u6548\uff1a%1": "\uc798\ubabb\ub41c URL: %1",
	"Error: %1": "\uc624\ub958: %1",
	"work_status-finished": "\uc644\ub8cc",
	"Unknown": "\uc54c \uc218 \uc5c6\uc74c",
	"\u300a%1\u300b\uff1a": "\u00ab%1\u00bb:",
	"HTTP status code %1.": "HTTP \uc0c1\ud0dc \ucf54\ub4dc %1.",
	"File size: %1.": "\ud30c\uc77c \ud06c\uae30: %1.",
	"\u7121\u6cd5\u5beb\u5165\u5716\u7247\u6a94\u6848 [%1]\u3002": "[%1] \uc774\ubbf8\uc9c0 \ud30c\uc77c\uc744 \uc4f8 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4.",
	"\u7121\u6cd5\u6210\u529f\u53d6\u5f97\u5716\u7247\u3002": "\uc774\ubbf8\uc9c0 \uac00\uc838\uc624\uae30\ub97c \uc2e4\ud328\ud588\uc2b5\ub2c8\ub2e4.",
	"\u82e5\u932f\u8aa4\u6301\u7e8c\u767c\u751f\uff0c\u60a8\u53ef\u4ee5\u8a2d\u5b9a skip_error=true \u4f86\u5ffd\u7565\u5716\u7247\u932f\u8aa4\u3002": "\uc624\ub958\uac00 \uc9c0\uc18d\ub418\uba74 \uc774\ubbf8\uc9c0 \uc624\ub958 \ubb34\uc2dc\ub97c \uc704\ud574 skip_error=true\ub97c \uc124\uc815\ud560 \uc218 \uc788\uc2b5\ub2c8\ub2e4.",
	"\u5716\u7247\u4e0b\u8f09\u932f\u8aa4": "\uc774\ubbf8\uc9c0 \ub2e4\uc6b4\ub85c\ub4dc \uc2e4\ud328",
	"Different url: %1 \u2260 %2": "\ucc28\uc774\uac00 \uc788\ub294 URL: %1 \u2260 %2",
	"\u8cbc\u4e0a": "\ubd99\uc5ec\ub123\uae30",
	"\u641c\u5c0b": "\uac80\uc0c9",
	"\u641c\u5c0b\u7d50\u679c": "\uac80\uc0c9 \uacb0\uacfc",
	"\u958b\u5553\u4e0b\u8f09\u76ee\u9304": "\ub2e4\uc6b4\ub85c\ub4dc \ub514\ub809\ud130\ub9ac \uc5f4\uae30",
	"\u4e0b\u8f09\u9078\u9805": "\ub2e4\uc6b4\ub85c\ub4dc \uc635\uc158",
	"\u672a\u9078\u64c7\u6a94\u6848\u6216\u76ee\u9304\u3002": "\uc120\ud0dd\ub41c \ud30c\uc77c \ub610\ub294 \ub514\ub809\ud130\ub9ac\uac00 \uc5c6\uc2b5\ub2c8\ub2e4.",
	"\u91cd\u8a2d\u4e0b\u8f09\u9078\u9805": "\ub2e4\uc6b4\ub85c\ub4dc \uc635\uc158 \ucd08\uae30\ud654",
	"\u6e05\u9664\u8a0a\u606f": "\ub85c\uadf8 \uc9c0\uc6b0\uae30",
	"\u958b\u59cb\u6aa2\u6e2c\u5b89\u88dd\u5305\u66f4\u65b0\u2026\u2026": "\ub9b4\ub9ac\uc2a4 \uc5c5\ub370\uc774\ud2b8 \ud655\uc778 \uc911...",
	"\u6709\u65b0\u7248\u5b89\u88dd\u5305\uff1a%1": "\uc0ac\uc6a9 \uac00\ub2a5\ud55c \ub9b4\ub9ac\uc2a4 \uc5c5\ub370\uc774\ud2b8: %1",
	"work_crawler-search_result_columns-site": "\uc0ac\uc774\ud2b8",
	"work_crawler-search_result_columns-completed": "\uc644\ub8cc",
	"work_crawler-search_result_columns-status": "\uc0c1\ud0dc",
	"\u932f\u8aa4\u539f\u56e0": "\uc624\ub958 \uc6d0\uc778",
	"\u4f5c\u54c1\u7db2\u7ad9": "\uc791\ud488 \uc6f9\uc0ac\uc774\ud2b8",
	"\u53d6\u6d88\u641c\u5c0b": "\uac80\uc0c9 \ucde8\uc18c",
	"\u7576\u524d\u8def\u5f91\uff1a%1": "\ud604\uc7ac \uacbd\ub85c: %1",
	"\u7e7c\u7e8c": "\uacc4\uc18d",
	"\u53d6\u6d88": "\ucde8\uc18c",
	"\u53d6\u6d88\u4e0b\u8f09": "\ub2e4\uc6b4\ub85c\ub4dc \ucde8\uc18c",
	"\u66f4\u65b0\u5b8c\u7562\u3002": "\uc5c5\ub370\uc774\ud2b8 \uc644\ub8cc.",
	"\u6aa2\u67e5\u66f4\u65b0\u4e2d\u2026\u2026": "\uc5c5\ub370\uc774\ud2b8 \ud655\uc778 \uc911...",
	"\u6709\u65b0\u7248\u672c\uff1a%1": "\uc5c5\ub370\uc774\ud2b8 \uc0ac\uc6a9 \uac00\ub2a5: %1",
	"\u66f4\u65b0\u5931\u6557\uff01": "\uc5c5\ub370\uc774\ud2b8 \uc2e4\ud328!",
	"dark theme": "\ub2e4\ud06c",
	"\u70ba\u53ef\u57f7\u884c\u6a94\u6216\u51fd\u5f0f\u5eab": "\uc2e4\ud589 \ud30c\uc77c \ub610\ub294 DLL \ud30c\uc77c\uc785\ub2c8\ub2e4.",
	"Remove empty directory: %1": "\ube48 \ub514\ub809\ud130\ub9ac \uc81c\uac70: %1",
	"Target exists: %1": "\ub300\uc0c1\uc774 \uc874\uc7ac\ud569\ub2c8\ub2e4: %1",
	"Changing working directory: [%1]\u2192[%2]": "\uc791\uc5c5 \ub514\ub809\ud130\ub9ac \ubcc0\uacbd: [%1]\u2192[%2]",
	"\u9805\u76ee\u8cc7\u8a0a\u7121\u6548\uff1a%1": "\uc720\ud6a8\ud558\uc9c0 \uc54a\uc740 \ud56d\ubaa9 \ub370\uc774\ud130: %1",
	"\u6a94\u6848\u4e26\u672a\u5728\u4e0b\u8f09\u968a\u5217\u4e2d\uff1a%1": "\ud30c\uc77c\uc774 \ub2e4\uc6b4\ub85c\ub4dc \ub300\uae30\uc5f4\uc5d0 \uc5c6\uc2b5\ub2c8\ub2e4: %1",
	"\u8cc7\u6e90\u4ecd\u5728\u4e0b\u8f09\u4e2d\uff1a": "\uacc4\uc18d \ub2e4\uc6b4\ub85c\ub4dc \uc911:",
	"Work information": "\uc791\ud488 \uc815\ubcf4",
	"TOC.identifier": "\uc2dd\ubcc4\uc790",
	"TOC.language": "\uc5b8\uc5b4",
	"TOC.subject": "\ud0dc\uadf8",
	"TOC.calibre:series": "\uc2dc\ub9ac\uc988",
	"word count": "\ub2e8\uc5b4 \uc218",
	"Waiting for all resources loaded...": "\ubaa8\ub4e0 \ub9ac\uc18c\uc2a4\uac00 \ub85c\ub4dc\ub418\uae30\ub97c \uae30\ub2e4\ub9ac\ub294 \uc911...",
	"\u79fb\u9664\u7a7a\u76ee\u9304\uff1a%1": "\ube48 \ub514\ub809\ud130\ub9ac\ub97c \uc81c\uac70\ud558\ub294 \uc911: %1",
	"Failed to get file: [%1]": "\ud30c\uc77c \uac00\uc838\uc624\uae30 \uc2e4\ud328: [%1]",
	"Invalid cookie?": "\uc720\ud6a8\ud558\uc9c0 \uc54a\uc740 \ucfe0\ud0a4?",
	"Retry %1/%2: %3": "\ub2e4\uc2dc \uc2dc\ub3c4 %1/%2: %3",
	"HTTP status code: %1 %2": "HTTP \uc0c1\ud0dc \ucf54\ub4dc: %1 %2",
	"\u6a94\u6848\u540d\u7a31\uff1a%1": "\ud30c\uc77c \uc774\ub984: %1",
	"Not Yet Implemented!": "\uc544\uc9c1 \uad6c\ud604\ub418\uc9c0 \uc54a\uc558\uc2b5\ub2c8\ub2e4!",
	"\u8a9e\u6cd5\u932f\u8aa4\uff01": "\uad6c\ubb38 \uc624\ub958!",
	"Illegal pattern: [%1]": "\uc798\ubabb\ub41c \ud328\ud134: [%1]",
	"Working directory: %1": "\uc791\uc5c5 \ub514\ub809\ud130\ub9ac: %1",
	"\u73fe\u6709%1\u689d%2\u8a0a\u606f\u5c1a\u672a\u7ffb\u8b6f\uff0c\u6b61\u8fce\u60a8\u4e00\u540c\u53c3\u8207\u7ffb\u8b6f\u8a0a\u606f\uff01": "There are currently %1 %2 messages that have not been translated. Welcome to translate with us!",
	"untranslated message count": "947",
	"local-language-name": "\ud55c\uad6d\uc5b4"
},
"ko-KR");

==> cejs-4.5.2.tgz: package/application/locale/resources/ko-KR.js <==
/*	Localized messages of CeL.
	This file is auto created by auto-generate tool: build.nodejs(.js) @ 2022.
*/'use strict';typeof CeL==='function'&&CeL.application.locale.gettext.set_text({
	"untranslated message count": "1000+",
	"\u6e05\u9664\u8a0a\u606f": "\ub85c\uadf8 \uc9c0\uc6b0\uae30",
	"\u8f38\u51fa\u683c\u5f0f": "\ucd9c\ub825 \ud615\uc2dd",
	"\u6642\u5340\uff1a": "\uc2dc\uac04\ub300:",
	"Loading...": "\ubd88\ub7ec\uc624\ub294 \uc911...",
	"\u6240\u6709\u570b\u5bb6": "\ubaa8\ub4e0 \uad6d\uac00",
	"\u554f\u984c\u56de\u5831": "\ud53c\ub4dc\ubc31",
	"France": "\ud504\ub791\uc2a4",
	"\u7d00\u5e74\u7dda\u5716\u9078\u9805\uff1a": "\ud0c0\uc784\ub77c\uc778 \uc635\uc158:",
	"Unix time": "\uc720\ub2c9\uc2a4 \uc2dc\uac04",
	"Julian calendar": "\uc728\ub9ac\uc6b0\uc2a4\ub825",
	"\u5206\u985e": "\uadf8\ub8f9",
	"\u4e2d\u570b": "\uc911\uad6d",
	"\ub2e8\uad70\uae30\uc6d0": "\ub2e8\uad70\uae30\uc6d0",
	"\u4e0a\u5f26": "1\ubd84\uae30",
	"Not Yet Implemented!": "\uc544\uc9c1 \uad6c\ud604\ub418\uc9c0 \uc54a\uc558\uc2b5\ub2c8\ub2e4!",
	"Language": "\uc5b8\uc5b4",
	"Invalid cookie?": "\uc720\ud6a8\ud558\uc9c0 \uc54a\uc740 \ucfe0\ud0a4?",
	"Retry %1/%2: %3": "\ub2e4\uc2dc \uc2dc\ub3c4 %1/%2: %3",
	"HTTP status code: %1 %2": "HTTP \uc0c1\ud0dc \ucf54\ub4dc: %1 %2",
	"\u6a94\u6848\u540d\u7a31\uff1a%1": "\ud30c\uc77c \uc774\ub984: %1",
	"Failed to get file: [%1]": "\ud30c\uc77c \uac00\uc838\uc624\uae30 \uc2e4\ud328: [%1]",
	"You may need to set %1 = %2!": "%1 = %2 \uc124\uc815\uc774 \ud544\uc694\ud560 \uc218 \uc788\uc2b5\ub2c8\ub2e4!",
	"Abandon change": "\ubcc0\uacbd\uc0ac\ud56d \ubc84\ub9ac\uae30",
	"Does not exist": "\uc874\uc7ac\ud558\uc9c0 \uc54a\uc74c",
	"\u7db2\u5740\u7121\u6548\uff1a%1": "\uc798\ubabb\ub41c URL: %1",
	"Edit %1": "%1 \ud3b8\uc9d1",
	"Missing page": "\ubb38\uc11c \uc5c6\uc74c",
	"Invalid page title": "\uc798\ubabb\ub41c \ubb38\uc11c \uc81c\ubaa9",
	"directories": "\ub514\ub809\ud130\ub9ac",
	"directory": "\ub514\ub809\ud130\ub9ac",
	"file": "\ud30c\uc77c",
	"files": "\ud30c\uc77c",
	"Using proxy server: %1": "\ud504\ub85d\uc2dc \uc11c\ubc84 \uc0ac\uc6a9: %1",
	"\u672a\u8a2d\u5b9a User-Agent\u3002": "User-Agent\uac00 \uc124\uc815\ub418\uc5b4 \uc788\uc9c0 \uc54a\uc2b5\ub2c8\ub2e4.",
	"\u7531\u547d\u4ee4\u5217": "\uba85\ub839 \uc904\uc5d0\uc11c",
	"fso_directories": "\ub514\ub809\ud130\ub9ac \uacbd\ub85c",
	"fso_directory": "\ub514\ub809\ud130\ub9ac \uacbd\ub85c",
	"fso_file": "\ud30c\uc77c \uacbd\ub85c",
	"fso_files": "\ud30c\uc77c \uacbd\ub85c",
	"\uff08\u672c\u6b21\u4e0b\u8f09\u5171\u8655\u7406%1\u500b\u5b57\uff09": "{\uc774 \ub2e4\uc6b4\uc740 \ucd1d %1 \ucc98\ub9ac\ud588\uc2b5\ub2c8\ub2e4 {{PLURAL:1|word|words}})",
	"\u300a%1\u300b\uff1a": "\u00ab%1\u00bb:",
	"HTTP status code %1.": "HTTP \uc0c1\ud0dc \ucf54\ub4dc %1.",
	"Error: %1": "\uc624\ub958: %1",
	"File size: %1.": "\ud30c\uc77c \ud06c\uae30: %1.",
	"\u7121\u6cd5\u5beb\u5165\u5716\u7247\u6a94\u6848 [%1]\u3002": "[%1] \uc774\ubbf8\uc9c0 \ud30c\uc77c\uc744 \uc4f8 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4.",
	"\u7121\u6cd5\u6210\u529f\u53d6\u5f97\u5716\u7247\u3002": "\uc774\ubbf8\uc9c0 \uac00\uc838\uc624\uae30\ub97c \uc2e4\ud328\ud588\uc2b5\ub2c8\ub2e4.",
	"\u82e5\u932f\u8aa4\u6301\u7e8c\u767c\u751f\uff0c\u60a8\u53ef\u4ee5\u8a2d\u5b9a skip_error=true \u4f86\u5ffd\u7565\u5716\u7247\u932f\u8aa4\u3002": "\uc624\ub958\uac00 \uc9c0\uc18d\ub418\uba74 \uc774\ubbf8\uc9c0 \uc624\ub958 \ubb34\uc2dc\ub97c \uc704\ud574 skip_error=true\ub97c \uc124\uc815\ud560 \uc218 \uc788\uc2b5\ub2c8\ub2e4.",
	"\u5716\u7247\u4e0b\u8f09\u932f\u8aa4": "\uc774\ubbf8\uc9c0 \ub2e4\uc6b4\ub85c\ub4dc \uc2e4\ud328",
	"Different url: %1 \u2260 %2": "\ucc28\uc774\uac00 \uc788\ub294 URL: %1 \u2260 %2",
	"Unknown": "\uc54c \uc218 \uc5c6\uc74c",
	"work_data.directory": "\uc2a4\ud1a0\ub9ac\uc9c0 \ub514\ub809\ud130\ub9ac",
	"work_data.id": "\uc791\ud488 ID",
	"work_data.title": "\uc791\ud488 \uc81c\ubaa9",
	"work_data.url": "URL",
	"work_status-finished": "\uc644\ub8cc",
	"Work information": "\uc791\ud488 \uc815\ubcf4",
	"Move %1 to %2 failed: %3": "%1\uc5d0\uc11c %2(\uc73c)\ub85c \uc774\ub3d9 \uc2e4\ud328: %3",
	"\u9805\u76ee\u8cc7\u8a0a\u7121\u6548\uff1a%1": "\uc720\ud6a8\ud558\uc9c0 \uc54a\uc740 \ud56d\ubaa9 \ub370\uc774\ud130: %1",
	"\u6a94\u6848\u4e26\u672a\u5728\u4e0b\u8f09\u968a\u5217\u4e2d\uff1a%1": "\ud30c\uc77c\uc774 \ub2e4\uc6b4\ub85c\ub4dc \ub300\uae30\uc5f4\uc5d0 \uc5c6\uc2b5\ub2c8\ub2e4: %1",
	"\u8cc7\u6e90\u4ecd\u5728\u4e0b\u8f09\u4e2d\uff1a": "\uacc4\uc18d \ub2e4\uc6b4\ub85c\ub4dc \uc911:",
	"TOC.calibre:series": "\uc2dc\ub9ac\uc988",
	"TOC.identifier": "\uc2dd\ubcc4\uc790",
	"TOC.language": "\uc5b8\uc5b4",
	"TOC.subject": "\ud0dc\uadf8",
	"word count": "\ub2e8\uc5b4 \uc218",
	"Waiting for all resources loaded...": "\ubaa8\ub4e0 \ub9ac\uc18c\uc2a4\uac00 \ub85c\ub4dc\ub418\uae30\ub97c \uae30\ub2e4\ub9ac\ub294 \uc911...",
	"\u79fb\u9664\u7a7a\u76ee\u9304\uff1a%1": "\ube48 \ub514\ub809\ud130\ub9ac\ub97c \uc81c\uac70\ud558\ub294 \uc911: %1",
	"Working directory: %1": "\uc791\uc5c5 \ub514\ub809\ud130\ub9ac: %1",
	"Changing working directory: [%1]\u2192[%2]": "\uc791\uc5c5 \ub514\ub809\ud130\ub9ac \ubcc0\uacbd: [%1]\u2192[%2]",
	"Italy": "\uc774\ud0c8\ub9ac\uc544",
	"Norway": "\ub178\ub974\uc6e8\uc774",
	"soon": "\uace7",
	"%1 {{PLURAL:%1|hour|hours}} ago": "%1{{PLURAL:%1|\uc2dc\uac04}} \uc804",
	"%1 {{PLURAL:%1|day|days}} ago": "%1{{PLURAL:%1|\uc77c}} \uc804",
	"%1 {{PLURAL:%1|day|days}} later": "%1{{PLURAL:%1|\uc77c}} \ud6c4",
	"\ud55c\uad6d": "\ud55c\uad6d",
	"\u8a9e\u6cd5\u932f\u8aa4\uff01": "\uad6c\ubb38 \uc624\ub958!",
	"Illegal pattern: [%1]": "\uc798\ubabb\ub41c \ud328\ud134: [%1]",
	"\u2191Back to TOC": "\u2191\ubaa9\ucc28\ub85c \ub3cc\uc544\uac00\uae30",
	"Cannot move to %1": "%1\ub85c \uc634\uae38 \uc218 \uc5c6\uc74c",
	"Namespaces: %1.": "\uc774\ub984\uacf5\uac04: %1.",
	"Change section title:": "\ubb38\ub2e8 \uc81c\ubaa9 \ubc14\uafb8\uae30:",
	"The requested robot task begins.": "\uc694\uccad\ud55c \ub85c\ubd07 \uc791\uc5c5\uc744 \uc2dc\uc791\ud569\ub2c8\ub2e4.",
	"Add warning messages.": "\uacbd\uace0 \uba54\uc2dc\uc9c0\ub97c \ucd94\uac00\ud569\ub2c8\ub2e4.",
	"The requested robot task finished.": "\uc694\uccad\ud55c \ub85c\ubd07 \uc791\uc5c5\uc774 \ub05d\ub0ac\uc2b5\ub2c8\ub2e4.",
	"Archiving operation": "\uae30\uad6c \uc544\uce74\uc774\ube0c \uc911",
	"Append %1 {{PLURAL:%1|topic|topics}}": "%1 {{PLURAL:%1|topic|topics}} \ucd94\uac00",
	"Remove %1 {{PLURAL:%1|topic|topics}}": "%1 {{PLURAL:%1|topic|topics}} \uc81c\uac70",
	"\u70ba\u53ef\u57f7\u884c\u6a94\u6216\u51fd\u5f0f\u5eab": "\uc2e4\ud589 \ud30c\uc77c \ub610\ub294 DLL \ud30c\uc77c\uc785\ub2c8\ub2e4.",
	"Cannot read directory: %1": "\ub514\ub809\ud130\ub9ac\ub97c \uc77d\uc744 \uc218 \uc5c6\uc2b5\ub2c8\ub2e4: %1",
	"Remove empty directory: %1": "\ube48 \ub514\ub809\ud130\ub9ac \uc81c\uac70: %1",
	"Target exists: %1": "\ub300\uc0c1\uc774 \uc874\uc7ac\ud569\ub2c8\ub2e4: %1",
	"\u641c\u5c0b\u7d50\u679c": "\uac80\uc0c9 \uacb0\uacfc",
	"\u4e0b\u8f09\u9078\u9805": "\ub2e4\uc6b4\ub85c\ub4dc \uc635\uc158",
	"\u958b\u5553\u4e0b\u8f09\u76ee\u9304": "\ub2e4\uc6b4\ub85c\ub4dc \ub514\ub809\ud130\ub9ac \uc5f4\uae30",
	"\u641c\u5c0b": "\uac80\uc0c9",
	"\u641c\u5c0b\u5404\u7db2\u7ad9\u4e26\u4e0b\u8f09\u4f5c\u54c1\u3002": "\uac01 \uc6f9\uc0ac\uc774\ud2b8\uc5d0\uc11c \uac80\uc0c9 \ubc0f work \ub2e4\uc6b4 \uc911",
	"\u8cbc\u4e0a": "\ubd99\uc5ec\ub123\uae30",
	"\u958b\u59cb\u6aa2\u6e2c\u5b89\u88dd\u5305\u66f4\u65b0\u2026\u2026": "\ub9b4\ub9ac\uc2a4 \uc5c5\ub370\uc774\ud2b8 \ud655\uc778 \uc911...",
	"\u6709\u65b0\u7248\u5b89\u88dd\u5305\uff1a%1": "\uc0ac\uc6a9 \uac00\ub2a5\ud55c \ub9b4\ub9ac\uc2a4 \uc5c5\ub370\uc774\ud2b8: %1",
	"work_crawler-search_result_columns-site": "\uc0ac\uc774\ud2b8",
	"work_crawler-search_result_columns-completed": "\uc644\ub8cc",
	"work_crawler-search_result_columns-status": "\uc0c1\ud0dc",
	"\u932f\u8aa4\u539f\u56e0": "\uc624\ub958 \uc6d0\uc778",
	"\u4f5c\u54c1\u7db2\u7ad9": "\uc791\ud488 \uc6f9\uc0ac\uc774\ud2b8",
	"\u53d6\u6d88\u641c\u5c0b": "\uac80\uc0c9 \ucde8\uc18c",
	"%1\u500b\u7db2\u7ad9\u4ecd\u5728\u641c\u5c0b\u4e2d\uff1a%2": "%1 {{PLURAL:%1|site is|sites are}} \uc544\uc9c1 \uac80\uc0c9 \uc911 %2",
	"\u7576\u524d\u8def\u5f91\uff1a%1": "\ud604\uc7ac \uacbd\ub85c: %1",
	"\u53d6\u6d88": "\ucde8\uc18c",
	"\u53d6\u6d88\u4e0b\u8f09": "\ub2e4\uc6b4\ub85c\ub4dc \ucde8\uc18c",
	"\u7e7c\u7e8c": "\uacc4\uc18d",
	"\u66f4\u65b0\u5b8c\u7562\u3002": "\uc5c5\ub370\uc774\ud2b8 \uc644\ub8cc.",
	"\u6aa2\u67e5\u66f4\u65b0\u4e2d\u2026\u2026": "\uc5c5\ub370\uc774\ud2b8 \ud655\uc778 \uc911...",
	"\u6709\u65b0\u7248\u672c\uff1a%1": "\uc5c5\ub370\uc774\ud2b8 \uc0ac\uc6a9 \uac00\ub2a5: %1",
	"\u66f4\u65b0\u5931\u6557\uff01": "\uc5c5\ub370\uc774\ud2b8 \uc2e4\ud328!",
	"local-language-name": "\ud55c\uad6d\uc5b4",
	"\u73fe\u6709%1\u689d%2\u8a0a\u606f\u5c1a\u672a\u7ffb\u8b6f\uff0c\u6b61\u8fce\u60a8\u4e00\u540c\u53c3\u8207\u7ffb\u8b6f\u8a0a\u606f\uff01": "There are currently %1 %2 messages that have not been translated. Welcome to translate with us!",
	"dark theme": "\ub2e4\ud06c",
	"\u91cd\u8a2d\u4e0b\u8f09\u9078\u9805": "\ub2e4\uc6b4\ub85c\ub4dc \uc635\uc158 \ucd08\uae30\ud654",
	"\u672a\u9078\u64c7\u6a94\u6848\u6216\u76ee\u9304\u3002": "\uc120\ud0dd\ub41c \ud30c\uc77c \ub610\ub294 \ub514\ub809\ud130\ub9ac\uac00 \uc5c6\uc2b5\ub2c8\ub2e4.",
	"option=value": "\uc635\uc158=\uac12",
	"Usage:": "\uc0ac\uc6a9\ubc95:",
	"Options:": "\uc635\uc158:"
},
"ko-KR");
